<?php
/*
Plugin Name: WpSilos2
Description: SEO Interlinking Silo Plugin
Version: 1.0
Author:Abbas Ravji
Author URI: www.wpsilos.com
*/
global $wpdb;
define( "INTERLINKS_URL", untrailingslashit( plugins_url( '/', __FILE__ ) ) );
define( "INTERLINKS_PATH", untrailingslashit( plugin_dir_path( __FILE__ ) ) );
//define( "INTERLINKS_TABLE", $wpdb->prefix. "faqs");
class InterLinksManager {
	
	function admin_enqueue(){
		wp_register_style('interlinks-css', INTERLINKS_URL . '/style.css');
		wp_enqueue_style('interlinks-css');
	}
	/** post / page **/
	function save_post($post_id){
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return;
		
		if ( isset($_POST['interlink_interlinks']) ) {
			if( ! wp_verify_nonce( $_POST['interlink_interlinks'], 'interlink_interlinks_nonce' ) ) {
		        wp_die( __( 'Cheatin&#8217; uh?' ) );
		    }
			
			global $post;
			if ( empty( $post ) ) { $post = get_post( $post_id ); }
        	
			$interlink_category = $_POST['interlink_category'];
			
			if ( $interlink_category != "no-category" ) {
				if ( $interlink_category == "add-new" ) {
					// add manual category to page 
					$term_name = $post->post_title;
					$term = term_exists( $term_name, 'category' );
					if ($term !== 0 && $term !== null) { // page title have same category term 
						$interlink_category = $term['term_id'];
					} else { // page title does not exists in category terms, add new 
						$interlink_category = wp_insert_term( $term_name, 'category' );
						if ( !is_wp_error( $interlink_category ) ) {
							$interlink_category = $interlink_category['term_id'];
						}
					}
				}
				// update interlink_category for the page 
				update_post_meta($post_id, "interlink_category", $interlink_category);
				// update interlink_page for the category 
				$interlink_page = get_option( $interlink_category . "_interlink_page" );
				if ( $interlink_page ) { // exists for the category
					update_option($interlink_category . "_interlink_page", $post_id);
				} else { // does not exists for the category
					update_option($interlink_category . "_interlink_page", $post_id);
				}
			} else {
				delete_post_meta($post_id, "interlink_category");
			}
		}	
	}
	
	function interlinks_form($post){
		wp_nonce_field( 'interlink_interlinks_nonce', 'interlink_interlinks', TRUE, TRUE );
		$interlink_category = get_post_meta($post->ID, "interlink_category", TRUE);
		$categories = get_categories(array(
			'hide_empty' => FALSE,
		));
		?>
		<label for='interlink_category'>Interlink Category</label>
		<select name='interlink_category' id='interlink_category'>
			<option value='add-new'>Add New</option>
			<option value='no-category'>No Interlink Category</option>
			<?php
			foreach($categories as $category) {
				$sel = $category->term_id == $interlink_category ? 'selected="selected"' : NULL;
				echo "<option value='{$category->term_id}' {$sel}>{$category->name}</option>"; 
			}
			?>
		</select>
		<?php
	}
     
	function interlinks_meta_box() {
		/*
		add_meta_box(
			'interlinks_boxid',
			'Category',
			array('InterLinksManager', 'interlinks_form'),
			'post',
			'side'
		);
		*/
		add_meta_box(
			'interlinks_boxid',
			'Interlink Category',
			array('InterLinksManager', 'interlinks_form'),
			'page',
			'side'
		);
	}
	
	function interlinks_type_columns( $defaults ) {
		$defaults['interlink-category'] = 'Interlink Category';
		return $defaults;
	}
	
	function interlinks_type_custom_column($column_name, $post_id){
		if ( $column_name == 'interlink-category') {
			$interlink_category = get_post_meta( $post_id, "interlink_category", TRUE);
			if ( $interlink_category && $interlink_category != "" ) {
				$term = get_term( $interlink_category, 'category' );
				if ($term) {
					echo $term->name;
				}
			}
		}
	}
	/** category **/
	function add_category_fields($taxonomy){
		?>
		<div class="form-field">
			<label for="interlink_page">Interlink Page</label>
			<?php
			$args = array(
			    'echo' => 1,
			    'name' => 'interlink_page'
			);
			wp_dropdown_pages( $args )
			?>
			<?php wp_nonce_field( 'interlink_interlinks_nonce', 'interlink_interlinks', TRUE, TRUE );?>
			<p class="description">Interlink Assigned Page</p>
		</div>
		<?php
	}

	function edit_category_fields($taxonomy){
		?>
		<tr class="form-field">
			<th valign="top" scope="row"><label for="interlink_page">Interlink Page</label></th>
			<td>
				<?php
				$interlink_page = get_option( $taxonomy->term_id . "_interlink_page" );
				$args = array(
				    'echo' => 1,
				    'selected' => $interlink_page,
				    'name' => 'interlink_page'
				);
				wp_dropdown_pages( $args )
				?>
				<?php wp_nonce_field( 'interlink_interlinks_nonce', 'interlink_interlinks', TRUE, TRUE );?>
				<p class="description">Interlink Assigned Page</p>
			</td>
		</tr>
		<?php
	}

	function save_category_fields( $cat_id ) {
		if ( isset($_POST['interlink_interlinks']) ) {
			if( ! wp_verify_nonce( $_POST['interlink_interlinks'], 'interlink_interlinks_nonce' ) ) {
		        wp_die( __( 'Cheatin&#8217; uh?' ) );
		    }
			// update assigned page here
			update_option( $cat_id."_interlink_page", $_POST['interlink_page'] );
			// update page according to category
			update_post_meta( $_POST['interlink_page'], "interlink_category", $cat_id);
		}
	}
 	
	function interlinks_settings_func(){
		if ( isset($_POST['interlink_interlinks']) ) {
			if( ! wp_verify_nonce( $_POST['interlink_interlinks'], 'interlink_interlinks_nonce' ) ) {
		        wp_die( __( 'Cheatin&#8217; uh?' ) );
		    }
			// save settings here
			update_option("interlinks_settings", $_POST['interlinks_settings']);
			echo '<div id="message" class="updated fade"><p><strong>InterLinks Settings updated successfully.</strong></p></div>';
		}
		$interlinks_settings = get_option("interlinks_settings", TRUE);
		?>
                <style>
                    .ads img{
                    
                        border:0;
                        text-decoration: none;
                    }
                    
                </style>
		<div class='wrap'>
                    <div style="float:left; width:70%">
			<div class="icon32" id="icon-link-manager"></div>
			<h2>InterLinks Settings</h2>
			<form action="options-general.php?page=interlinks-settings" method="post">
				<?php wp_nonce_field( 'interlink_interlinks_nonce', 'interlink_interlinks', TRUE, TRUE ); ?>
				<p style="width: 300px;">
					<label for='number_of_recent_posts'>Number of Recent Posts:</label>
					<input class="widefat" id="number_of_recent_posts" name="interlinks_settings[number_of_recent_posts]" type="text" value="<?php if(isset($interlinks_settings["number_of_recent_posts"])) echo $interlinks_settings["number_of_recent_posts"]; ?>" />
				</p>
                                
                                <p style="width: 300px;">
					<label for='number_of_recent_posts'>Number of Related Posts:</label>
					<input class="widefat" id="number_of_recent_posts" name="interlinks_settings[number_of_related_posts]" type="text" value="<?php if(isset($interlinks_settings["number_of_related_posts"])) echo $interlinks_settings["number_of_related_posts"]; ?>" />
				</p>
				<p style="width: 300px;">
					<label for='title_heading'>Title Heading:</label>
					<select name="interlinks_settings[title_heading]" id="title_heading" class="widefat" >
						<option value="<h1>|</h1>" <?php echo $interlinks_settings['title_heading'] == "<h1>|</h1>" ? 'selected="selected"' : NULL;?>>H1</option>
						<option value="<h2>|</h2>" <?php echo $interlinks_settings['title_heading'] == "<h2>|</h2>" ? 'selected="selected"' : NULL;?>>H2</option>
						<option value="<h3>|</h3>" <?php echo $interlinks_settings['title_heading'] == "<h3>|</h3>" ? 'selected="selected"' : NULL;?>>H3</option>
						<option value="<h4>|</h4>" <?php echo $interlinks_settings['title_heading'] == "<h4>|</h4>" ? 'selected="selected"' : NULL;?>>H4</option>
						<option value="<h5>|</h5>" <?php echo $interlinks_settings['title_heading'] == "<h5>|</h5>" ? 'selected="selected"' : NULL;?>>H5</option>
						<option value="<h6>|</h6>" <?php echo $interlinks_settings['title_heading'] == "<h6>|</h6>" ? 'selected="selected"' : NULL;?>>H6</option>
					</select>
					
					
				</p>
				<p style="width: 300px;">
					<label for='home_title'>Home Title:</label>
					<input class="widefat" id="home_title" name="interlinks_settings[home_title]" type="text" value="<?php if(isset($interlinks_settings['home_title'])) echo $interlinks_settings['home_title']; ?>" />
				</p>
                               <p style="width: 300px;">
					<label for='pages_title'>Home Anchor Text:</label>
					<input class="widefat" id="pages_title" name="interlinks_settings[pages_title]" type="text" value="<?php if(!isset($interlinks_settings['posts_title']) && $interlinks_settings['posts_title']=='') echo "Home";  else echo $interlinks_settings['pages_title']; ?>" />
				</p>
				
                                
                               
				<p style="width: 300px;">
					<label for='category_title'>Related Post Title:</label>
					<input class="widefat" id="category_title" name="interlinks_settings[related_title]" type="text" value="<?php if(isset($interlinks_settings['related_title'])) echo $interlinks_settings['related_title']; ?>" />
				</p>
				
				<p style="width: 300px;">
					<label for='posts_title'>Recent Post Title:</label>
					<input class="widefat" id="posts_title" name="interlinks_settings[posts_title]" type="text" value="<?php if($interlinks_settings['posts_title']=='') echo "Recent Posts";  else echo $interlinks_settings['posts_title']; ?>" />
				</p>
                                <p style="width: 300px;">
					<label for='posts_title'>Dont Show Home Link On Posts:</label><br>
                                        <input type="checkbox" name="interlinks_settings[dont_show_home]" <?php if(isset($interlinks_settings['dont_show_home']) && $interlinks_settings['dont_show_home']==true ){ ?>checked="checked"<?php } ?> />  
            				</p>
                                
				<p>
					<input type='submit' name='btnSaveSettings' id='btnSaveSettings' value="Save Settings" class="button-secondary" />
				</p>
			</form>
		</div>
                    
                    <div style="width:30%; float: left">
                        <div class="ads">
                            <a target="_blank" href="http://www.abbasravji.com/silo1"><img src="http://www.socisynd.com/SiloPlugin/position1.gif"></a>
                        </div>
                        
                         <div class="ads">
                            <a target="_blank" href="http://www.abbasravji.com/silo2"><img src="http://www.socisynd.com/SiloPlugin/position2.jpg"></a>
                        </div>
                        
                         <div class="ads">
                            <a target="_blank" href="http://www.abbasravji.com/silo3"><img src="http://www.socisynd.com/SiloPlugin/position3.gif"></a>
                        </div>
                             
                        
                        
                    </div>
                </div>
                
		<?php
	}
	
	function admin_menu() {
		add_options_page('wpsilos Settings', 'wpsilos Settings', 'manage_options', 'interlinks-settings', array( 'InterLinksManager', 'interlinks_settings_func' ));
	}
}

/** pages **/
//add_action( 'add_meta_boxes', array( 'InterLinksManager', 'interlinks_meta_box' ) );
//add_action( 'admin_enqueue_scripts', array( 'InterLinksManager', 'admin_enqueue' ) );
add_action( 'save_post', array( 'InterLinksManager', 'save_post' ) );
add_filter( 'manage_page_posts_columns', array( 'InterLinksManager', 'interlinks_type_columns' ) );
add_action('manage_page_posts_custom_column', array( 'InterLinksManager', 'interlinks_type_custom_column' ), 10, 2);

/** category management **/
add_action( 'category_add_form_fields' , array( 'InterLinksManager' , 'add_category_fields') , 10 , 10 );
add_action( 'category_edit_form_fields' , array( 'InterLinksManager' , 'edit_category_fields') );
add_action( 'edited_category' , array( 'InterLinksManager' , 'save_category_fields' ) , 10 , 2 );
add_action( 'created_category', array( 'InterLinksManager' , 'save_category_fields' ) , 10 , 2 );

/**custom tables**/
//register_activation_hook( __FILE__, array( 'InterLinksManager', 'install' ) );
add_action( 'admin_menu', array( 'InterLinksManager', 'admin_menu' ) );

/** includes **/
include_once ("widget.php");